@@ -11,7 +11,6 @@
 
 #include <time.h>
 #include <sched.h>	/* For __CPU_SETSIZE */
-#include <stdlib.h>
 #include <limits.h>
 
 #ifdef HAVE_SYS_SYSMACROS_H
@@ -125,21 +124,14 @@
 #define SREALLOC(S, TYPE, SIZE)	do {								 \
 					TYPE *_p_ = S;						 \
    				   	if (SIZE) {						 \
-						void *_ptr = NULL;				 \
-						int error = posix_memalign(&_ptr, 16, (SIZE));	 \
-						if (error || (_ptr == NULL)) {			 \
+						if ((S = (TYPE *) realloc(S, (SIZE))) == NULL) { \
 				         		perror("realloc");			 \
 				         		exit(4);				 \
 				      		}						 \
-						S = (TYPE *)_ptr;				 \
 				      		/* If the ptr was null, then it's a malloc() */	 \
 						if (!_p_) {					 \
 							memset(S, 0, (SIZE));			 \
 						}						 \
-						else {						 \
-							memcpy(S, _p_, (SIZE));			 \
-							free(_p_);				 \
-						}						 \
 				   	}							 \
 					if (!S) {						 \
 						/* Should never happen */			 \
