@@ -567,7 +567,7 @@ __print_funct_t raw_print_disk_stats(struct activity *a, char *timestr, int curr
 		pval((unsigned long long) sdp->wr_sect, (unsigned long long) sdc->wr_sect);
 		printf(" tot_ticks:");
 		pval((unsigned long long) sdp->tot_ticks, (unsigned long long) sdc->tot_ticks);
-		pfield(NULL, 0); /* Skip avgrq-sz */
+		pfield(NULL, 0); /* Skip areq-sz */
 		printf(" %s:", pfield(NULL, 0));
 		pval((unsigned long long) sdp->rq_ticks, (unsigned long long) sdc->rq_ticks);
 		printf("\n");
